Change Log
==========

0.1.0 (20/06/2021)
-Sixth Release

### Added

## New
__version__() - method
__info__() - method

## Physics Math 
New type of calculation of basic physics 

## Moefied 
galtoL() - method
Ltogal() - method